@@ -1,13 +1,11 @@
 """Processing functions for the ZeroDose model."""
 
 import torch
-import torch.nn as nn
 import torchio as tio
 from torchio import SpatialTransform
 from torchio.data.subject import Subject
 
 from zerodose import processing
-from zerodose import utils
 
 
 _X_MIN_MNI = 0
@@ -38,7 +36,7 @@ def _crop_192_to_mni(arr: torch.Tensor) -> torch.Tensor:
     return parr
 
 
-class PadAndCropToMNI(SpatialTransform):
+class PadAndCropMNI(SpatialTransform):
     """Pad the MNI image to 192x192x192."""
 
     def __init__(self, is_inverse=False, **kwargs) -> None:
@@ -63,7 +61,23 @@ class PadAndCropToMNI(SpatialTransform):
 
     def inverse(self):
         """Returns the inverse transform."""
-        return PadAndCropToMNI(is_inverse=True)
+        return PadAndCropMNI(is_inverse=True)
+
+
+class Binarize(SpatialTransform):
+    """Binarize an image based on a threshhold."""
+
+    def __init__(self, threshold=0.5, **kwargs) -> None:
+        """Initialize the transform."""
+        self.threshold = threshold
+        super().__init__(**kwargs)
+
+    def apply_transform(self, subject: Subject) -> Subject:
+        """Apply the transform to the subject."""
+        for image in self.get_images(subject):
+            data = image.data
+            image.set_data(data > self.threshold)
+        return subject
 
 
 def _pad(image: tio.Image) -> None:
@@ -100,43 +114,3 @@ def _to_float(image: tio.Image) -> None:
     _data = image.numpy().astype("f")
     data = torch.as_tensor(_data)
     image.set_data(data)
-
-
-class QuantileNormalization(nn.Module):
-    """Quantile normalization of the sbPET image."""
-
-    def __init__(
-        self,
-        quantile,
-        sigma_normalization=3,
-    ) -> None:
-        """Initialize the normalization module."""
-        super().__init__()
-        self.quantile = quantile
-        self.smooth_normalization = utils.GaussianSmoothing(
-            channels=1,
-            kernel_size=5 * sigma_normalization,
-            sigma=sigma_normalization,
-            dim=3,
-        )
-
-    def forward(
-        self, pet: torch.Tensor, sbpet: torch.Tensor, mask: torch.Tensor
-    ) -> torch.Tensor:
-        """Normalize the sbPET image."""
-        return self._scale_sbpet(pet, sbpet, mask)
-
-    def _get_normalization_mask(self, pet, mask):
-        qt = torch.quantile(pet[mask], self.quantile)
-        norm_mask = mask & (pet > qt)
-        return norm_mask
-
-    def _scale_sbpet(self, pet, sbpet, mask):
-        for _i in range(2):
-            pet_blurred = self.smooth_normalization(pet)
-            norm_mask = self._get_normalization_mask(pet_blurred, mask)
-            norm_const = torch.mean(pet[norm_mask]) / torch.mean(sbpet[norm_mask])
-            sbpet *= norm_const
-            sbpet[~mask] = pet[~mask]
-
-        return sbpet
